Skip to contents

The DISPUTER_DEV_CHECK environment variable is used determine whether parameter checks on disputeR functions are run during a session.

Usage

dis_dev_check(dev_check = FALSE)

Arguments

dev_check

Required logical scalar; should parameter checks on disputeR functions be conducted? If FALSE (default), all checks for disputeR function parameters will be skipped. This is the ideal situation for end users who are using a function with properly configured disputeR functions within it. For developers who are checking the configuration of disputeR functions, setting dev_check to TRUE can aid with troubleshooting. See the vignette on vignette("developing", package = "disputeR") for details on how to use this function.

Value

This function writes to your session's environment variables, but does not explicitly return any value.

Details

Since this function is meant to be used interactively, internal validation of its arguments cannot be skipped. See the vignette on vignette("developing", package = "disputeR") for details.