Skip to contents

The DISPUTER_FACT_CHECK environment variable is used determine whether disputeR checks are run globally within a package or Shiny app.

Usage

dis_fact_check(fact_check = TRUE)

Arguments

fact_check

Required logical scalar; should disputeR fact checking be conducted? If TRUE (default), all parameter checks within a project or Shiny app will be run. When set to FALSE, all checks will be skipped unless they are specifically overridden with a function's fact_check argument. See the vignette on vignette("developing", package = "disputeR") for details on how to use this function.

Value

This function writes to your session's environment variables, but does not explicitly return any value.

Details

Since this function is meant to be used interactively, internal validation of its arguments cannot be skipped. See the vignette on vignette("developing", package = "disputeR") for details.

Examples

dis_fact_check()