The DISPUTER_DEV_CHECK environment variable is used
determine whether parameter checks on disputeR functions are run
during a session.
Arguments
- dev_check
Required logical scalar; should parameter checks on
disputeRfunctions be conducted? IfFALSE(default), all checks fordisputeRfunction parameters will be skipped. This is the ideal situation for end users who are using a function with properly configureddisputeRfunctions within it. For developers who are checking the configuration ofdisputeRfunctions, settingdev_checktoTRUEcan aid with troubleshooting. See the vignette onvignette("developing", package = "disputeR")for details on how to use this function.
Value
This function writes to your session's environment variables, but does not explicitly return any value.
Details
Since this function is meant to be used interactively, internal validation
of its arguments cannot be skipped. See the vignette on
vignette("developing", package = "disputeR") for details.