The DISPUTER_FACT_CHECK environment variable is used
determine whether disputeR checks are run globally within a package
or Shiny app.
Arguments
- fact_check
Required logical scalar; should
disputeRfact checking be conducted? IfTRUE(default), all parameter checks within a project or Shiny app will be run. When set toFALSE, all checks will be skipped unless they are specifically overridden with a function'sfact_checkargument. See the vignette onvignette("developing", package = "disputeR")for details on how to use this function.
Value
This function writes to your session's environment variables, but does not explicitly return any value.
Details
Since this function is meant to be used interactively, internal validation
of its arguments cannot be skipped. See the vignette on
vignette("developing", package = "disputeR") for details.