Determine Whether an Indefinite Article is Needed for a Particular Class
Source:R/dis_indefinite.R
dis_indefinite.RdThis function returns the correct indefinite article based on the class of the input.
Value
If the input is an integer or the class of the input is included in
indefinite_class, the function will return "an". Otherwise,
the function will return "a".
Details
See the vignette on vignette("developing", package = "disputeR")
for details about internal validation of arguments for this function. Unlike
the core functions, dis_param does not have a fact_check
argument. The vignette("developing", package = "disputeR") vignette
includes details on how to implement that functionality around dis_param.