Create the default message used when a parameter is found to
be have an invalid value.
Usage
dis_msg_valid()
Value
A character string with the default message.
Examples
dis_msg_valid()#>#> "{.arg {param}} must be a valid value for the parameter {.arg {param}}, not {.code {x}}." #> i #> "Valid arguments for {.arg {param}} are: {.code {valid}}."